* Project: inequality in Germany
*
* Author: Michele Battisti, Jan-Philipp Suchta
*
* MASTER DO FILE
*
* Date created:
* Last modified:
*
* Input: SOEP long dataset v30 and v31
* Output: 

clear 
set more off
set linesize 255
cd \

**** Part to be adapted to each computer

* Philipp's computer
*global orig "G:\PROJ\HIWIS\Jan-Philipp\philipp\statadata" /* This is where the soep long v30 dataset sits */
*global root "G:\PROJ\HIWIS\Jan-Philipp\philipp\ungleichheit" /* This should point to our shared folder in One Drive where we keep do files, log files and figures */

* Michele's laptop
global orig "C:\Users\battisti.IFO\Documents\datasets\soep31core\statadata" /* This is where the original dataset sits */
*global root "C:\Users\battisti.IFO\OneDrive\ungleichheit\"         /* This is our shared folder in One Drive where we keep do files, log files and figures */
global root "C:\Users\battisti.IFO\Documents\datasets\soep31core"

**** End of part to be adapted to each computer

* Set globals for other folders
* These should work for both our computers without being modified
* because they use the root global that we just created
global log "$root/log"
global prog "$root/prog"
global fig "$root/fig"
global data "$root/data" /* Ideally we shoudl avoid very large datasets in this folder. Better to avoid creating those, or to save them in the orig folder */

********************
* Data preparation *
********************
*do $prog/01.01.01.do /* reads in soep long, variables we need */

* Create a log file with the list of all files
*capture log close
*log using "$log/list.files.log", replace
dir $prog\*
dir $log\*
dir $data\*
dir $orig\*
*log close

*log using "$root\log\01.smcl", replace
clear
set more off
local i = 97
foreach y in n o p {
use "$orig/`y'pequiv.dta", clear
gen syear= 1900+`i'
renvars *`i', postsub(`i' )
drop `y'hhnr
save "$root/data/merge`i'", replace
local ++i
}

local i = 00
foreach y in q r s t u v w x y z  {
use "$orig/`y'pequiv.dta", clear
gen syear= 2000+ `i'
renvars *`i', postsub(0`i' )
drop `y'hhnr
save "$root/data/merge0`i'", replace
local ++i
}

local i = 10
foreach y in ba bb bc bd be  {
use "$orig/`y'pequiv.dta", clear
gen syear= 2000+ `i'
renvars *`i', postsub(`i' )
drop `y'hhnr
save "$root/data/merge`i'", replace
local ++i
}

use "$root/data/merge97", clear
forvalues n=98/99{
append using "$root/data/merge`n'"
}

forvalues n=0/9{
append using "$root/data/merge0`n'"
}

forvalues n=10/14{
append using "$root/data/merge`n'"
}

rename persnr  pid
rename hhnrakt cid
rename hhnr  hid

merge 1:1 syear pid using "C:\Users\battisti.IFO\Documents\datasets\soep30long\pl.dta", keepusing(plb0241 plb0186)
drop if syear<1997
save "$orig\pequiv2.dta", replace

use "$orig\pequiv2.dta" , clear
quietly: mvdecode _all, mv(-1=.\-2=.\-3=.)
save "$root\data\decoded2.dta", replace

use "$orig\ppfad.dta", clear
keep *hhnr *pop persnr *migback
gen syear=.
local i = 97
foreach y in n o p {
rename `y'hhnr hhnr19`i'
rename `y'pop pop19`i'
local ++i
}

local i = 00
foreach y in q r s t u v w x y z  {
rename `y'hhnr hhnr200`i'
rename `y'pop pop200`i'
local ++i
}

local i = 10
foreach y in ba bb bc bd be  {
rename `y'hhnr hhnr20`i'
rename `y'pop pop20`i'
local ++i
}

keep hhnr* pop* persnr *migback
drop hhnr
rename persnr pid
reshape long hhnr pop, i(pid) j(syear)
drop if hhnr==-2 | hhnr==. | hhnr==-3
quietly: mvdecode _all, mv(-1=.\-2=.\-3=.)
save "$root\data\pfadcoremerge.dta", replace

*desired and actual hours from 2014
use "G:\PROJ\HIWIS\Jan-Philipp\philipp\statadata\bep.dta", clear
keep hhnr hhnrakt persnr bep46 bep48
recode bep46 bep48 (-2 = .) (-1 = .) (-3 = .) (-5 = .)
replace bep46= bep46/10
replace bep48= bep48/10
rename bep46 plb0241merge
rename bep48 plb0186merge
rename persnr  pid
rename hhnrakt cid
rename hhnr  hid
gen syear=2014
save "$root\data\hours", replace

use "$root\data\decoded2.dta", clear
drop _merge
merge 1:1 pid syear using "$root\data\hours"
replace plb0241 = plb0241merge if _merge==3
replace plb0186 = plb0186merge if _merge==3
drop _merge
merge 1:1 pid syear using "$root\data\pfadcoremerge.dta"
drop if _merge==2
keep if pop<3
svyset [weight=w11101]

*******************************
*Variables
*******************************
*age
gen			age=.
replace		age=d11101
label var	age "Age"

gen			age2= age^2
label var	age2 "Age squared"

gen			agegroup=.
replace		agegroup=1 if d11101<35 & d11101!=.
replace		agegroup=2 if d11101>34 & d11101<50 & d11101!=.
replace		agegroup=3 if d11101>51 & d11101!=.
label define agegroups 1 "34 years or younger" 2 "35-49 years old" 3 "50 years or older"
label val	agegroup agegroups
label var	agegroup "Age groups"
tab			agegroup, gen(agr)

*Geschlecht
gen			gender=.
replace		gender=d11102ll
recode		gender (1=0) (2=1)
label var	gender "Gender"
label define gender 0 "Male" 1 "Female"
label val	gender gender

*Marital status
gen			marital=.
replace		marital=d11104
label var	marital "Marital Status"
label define marital 1 "Married" 2 "Single" 3 "Widowed" 4 "Divorced" 5 "Separated"
label val	marital marital

tabulate	marital, gen(marital)


*Number of persons in HH
gen			persons=.
replace		persons=d11106
label var	persons "Number of persons in HH"

*Number of children
gen			children=.
replace		children=d11107
label var	children "Number of children in HH"

*Number of adults
gen			adults=.
replace		adults=d11106-d11107
label var	adults "Number of adults in HH"

*years of education
gen			edu=.
replace		edu= d11108
label var	edu "Education"
tabulate	edu, gen(edu)

*Migration background
gen			migration=.
replace		migration=migback
label var	migration "Migration background"
tabulate	migration, gen(migration)

*Arbeitsstatus
gen				emp_hours=e11101
gen logemp_hours = log(emp_hours)

gen				emp_stat=.
replace			emp_stat=1 if e11101>=1560 & e11101!=. & e11102==1
replace			emp_stat=2 if e11101<1560 & e11101>=52 & e11102==1 & e11101!=.
replace			emp_stat=3 if e11102==0

gen				fulltime=. 
replace fulltime =1 if emp_stat==1
replace fulltime =0 if emp_stat==2 | emp_stat==3

gen				parttime=. 
replace parttime =1 if emp_stat==2
replace parttime =0 if emp_stat==1 | emp_stat==3

gen				notworking=. 
replace notworking =1 if emp_stat==3
replace notworking =0 if emp_stat==1 | emp_stat==2

gen 		i11101_real=.
replace 	i11101_real= i11101*100/y11101
label var	i11101_real "Real net household income Pre-Government"

gen 		i11102_real=.
replace 	i11102_real= i11102*100/y11101
label var	i11102_real "Real net household income Post-Government"

gen			lab_inc=.
replace		lab_inc= i11110
label var	lab_inc "Individual labor income"

gen			lab_inc_siab=.
replace		lab_inc_siab= i11110 - iself
label var	lab_inc_siab "Individual labor income without self-employment"

gen			hourly_wage=.
replace		hourly_wage= lab_inc / emp_hours
label var	hourly_wage "Hourly wage"

gen			hourly_wage_siab=.
replace		hourly_wage_siab= lab_inc_siab / emp_hours
label var	hourly_wage_siab "Hourly wage siab"

gen			lab_inc_siab_real=.
replace		lab_inc_siab_real= lab_inc_siab*100/y11101
label var	lab_inc_siab_real "Individual real labor income"

gen			lab_inc_real=.
replace		lab_inc_real= lab_inc*100/y11101
label var	lab_inc_real "Individual real labor income"

gen			hourly_wage_siab_real=.
replace		hourly_wage_siab_real= hourly_wage_siab*100/y11101
label var	hourly_wage_siab_real "Real hourly wage without self-employment"

gen			hourly_wage_real=.
replace		hourly_wage_real= hourly_wage*100/y11101
label var	hourly_wage_real "Real hourly wage"

gen			ln_hourly_wage_real= log(hourly_wage_real)
label var	ln_hourly_wage_real "Log real hourly wage"

gen			ln_lab_inc_real = log(lab_inc_real)
label var	ln_lab_inc_real "Log individual real labor income"

gen			edu_health=.
local n =1998
foreach i in ///
3007.057737 ///
3074.907836 ///
3135.905241 ///
3208.574967 ///
3306.870256 ///
3374.027852 ///
3407.127357 ///
3378.11596 ///
3484.906462 ///
3527.938083 ///
3690.715809 ///
3842.979378 ///
4084.590296 ///
4258.215033 ///
4336.543253 ///
4531.418147 ///
4605.94757 {
replace edu_health= `i' if syear==`n'
local ++n
}
label var	edu_health "Education and health spending"

gen 		erwachsene_hh =.
replace 	erwachsene_hh = d11106 - h11101
label var	erwachsene_hh "Anzahl der über 14-Jährigen"

gen 		kinder_hh =.
replace 	kinder_hh = h11101
label var	kinder_hh "Anzahl der unter 14-Jährigen"

gen			oecd_equi =.
replace		oecd_equi = 1 + 0.5*(erwachsene_hh - 1) + 0.3*kinder_hh
label var	oecd_equi "Äquivalenzfaktor OECD"

gen			income_pre =.
replace		income_pre =i11101/oecd_equi
label var	income_pre "Equivalized income pre-Government"

gen			income_real_pre =.
replace		income_real_pre =i11101_real/oecd_equi
label var	income_real_pre "Equivalized real income pre-Government"

gen			income_post =.
replace		income_post =i11102/oecd_equi
label var	income_post "Equivalized income post-Government"

gen			lab_inc_hh =.
replace		lab_inc_hh =i11103/oecd_equi
label var	lab_inc_hh "Equivalized household labour income"

gen			income_real_post =.
replace		income_real_post =i11102_real/oecd_equi
label var	income_real_post "Equivalized real income Post-Government"

gen			income_edu_health= (i11102 + edu_health)/oecd_equi
label var	income_edu_health "Household income post-government plus edu and health spending"

gen			income_edu_health_real= income_edu_health*100/y11101
label var	income_edu_health_real "Real household income post-government plus edu and health spending"

gen 		deshours =.
replace 	deshours = plb0241 if plb0241>-1
label var	deshours "Desired working hours"

gen 		actualhours =.
replace 	actualhours = plb0186 if plb0186>-1
label var	actualhours "Actual working hours"

gen 		wishdiff = actualhours - deshours
replace 	wishdiff =. if actualhours==. & deshours==.
label var	wishdiff "Difference actual desired hours"

gen 		lessthanwish = (wishdiff<-4.9)
replace 	lessthanwish =. if wishdiff==.
label var	lessthanwish "Works less than wishes"

gen 		morethanwish = (wishdiff> 4.9)
replace 	morethanwish =. if wishdiff==.
label var	morethanwish "Works more than wishes"

***
save "$root\data\preped2.dta", replace

********************************************************************************
* Gini real gross labour income
********************************************************************************
clear all
set more off
use "$root\data\preped2.dta", clear
gen gini_year=.
gen gini_lab_inc=.

ineqdeco lab_inc_real [aweight=w11101] if age>15 & age<66, by(syear)
local n = 1
forvalues i = 2001/2013 {
replace gini_lab_inc= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}
********************************************************************************
* Gini hourly wages, comparable to SIAB
********************************************************************************
clear all
set more off
use "$root\data\preped2.dta", clear
gen gini_year=.
gen gini_lab_inc=.
gen gini_wages=.
keep if age>=16 & age<66
keep if fulltime==1

ineqdeco hourly_wage_siab_real [aweight=w11101], by(syear)
local n = 1
forvalues i = 1997/2014 {
replace gini_wages= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}
********************************************************************************
* Gini of employed and of all workers
********************************************************************************
clear all
set more off
use "$root\data\preped2.dta", clear
gen gini_year=.
gen gini_lab_inc_employed=.
gen gini_lab_inc_all=.

ineqdeco lab_inc_real [aweight=w11101] if age>15 & age<66, by(syear)
local n = 1
forvalues i = 1997/2014 {
replace gini_lab_inc_employed= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}

ineqdec0 lab_inc_real [aweight=w11101] if age>15 & age<66, by(syear)
local n = 1
forvalues i = 1997/2014 {
replace gini_lab_inc_all= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}

********************************************************************************
* Gini of labour force
********************************************************************************
clear all
set more off
use "$root\data\preped2.dta", clear
gen gini_year=.
gen gini_lab_inc_all=.

ineqdec0 lab_inc_real [aweight=w11101] if age>15 & age<66, by(syear)
local n = 1
forvalues i = 1997/2014 {
replace gini_lab_inc_all= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}

*Arbeitslosenzahlen von: https://www.destatis.de/DE/ZahlenFakten/Indikatoren/LangeReihen/Arbeitsmarkt/lrarb001.html

********************************************************************************
* Gini hourly wages, hours and labour income
********************************************************************************
clear all
set more off
use "$root\data\preped2.dta", clear
gen gini_year=.
gen gini_hourly_wages=.
gen gini_lab_inc=.
gen gini_hours=.

ineqdeco hourly_wage_real [aweight=w11101] if age>15 & age<66, by(syear)
local n = 1
forvalues i = 1998/2014 {
replace gini_hourly_wages= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}

ineqdeco lab_inc_real [aweight=w11101] if age>15 & age<66, by(syear)
local n = 1
forvalues i = 1998/2014 {
replace gini_lab_inc= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}

ineqdeco e11101 [aweight=w11101] if age>15 & age<66, by(syear)
local n = 1
forvalues i = 1998/2014 {
replace gini_hours= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}

********************************************************************************
* Full time, part time, not working among women
********************************************************************************
use "$root\data\preped2.dta", clear
keep if gender==1
keep if age>24 & age<66
collapse (mean) fulltime parttime notworking if gender==1 [aweight=w11101], by(syear)

********************************************************************************
* Desired and actual part time, women
********************************************************************************
use "$root\data\preped2.dta", clear
keep if gender==1 
keep if age>24 & age<=65
*drop if syear==2014
gen desire =.
replace desire = 1 if deshours> 30 				& deshours!=.
replace desire = 0 if deshours<=30 & deshours>=5 & deshours!=.
gen actual =.
replace actual = 1 if actualhours> 30 & actualhours!=.
replace actual = 0 if actualhours<=30 & actualhours>=5 & actualhours!=.
gen wantsfulltime = (actual==0 & desire==1) if actual==0 & desire!=.
gen wantsparttime = (actual==1 & desire==0) if actual==1 & desire!=.
collapse (mean) wantsfulltime wantsparttime [aweight=w11101], by(syear)

********************************************************************************
* Population shares and wages of different groups
********************************************************************************
clear all
set more off
use "$root\data\preped2.dta", clear
keep if age>24 & age<66
keep if fulltime==1
* gender
tab gender [aweight=w11101] if syear==1998 &  notworking==0
tab gender [aweight=w11101] if syear==2014 &  notworking==0
sum ln_lab_inc_real [aweight=w11101] if syear==1998 & gender==1 & notworking==0
sum ln_lab_inc_real [aweight=w11101] if syear==2014 & gender==1 & notworking==0
sum ln_lab_inc_real [aweight=w11101] if syear==1998 & gender==0 & notworking==0
sum ln_lab_inc_real [aweight=w11101] if syear==2014 & gender==0 & notworking==0
* age groups
tab agegroup [aweight=w11101] if syear==1998 & notworking==0
tab agegroup [aweight=w11101] if syear==2014 & notworking==0
bysort agegroup: sum ln_lab_inc_real [aweight=w11101] if syear==1998 & notworking==0
bysort agegroup: sum ln_lab_inc_real [aweight=w11101] if syear==2014 & notworking==0
* education
tab edu [aweight=w11101] if syear==1998 & notworking==0
tab edu [aweight=w11101] if syear==2014 & notworking==0
bysort edu: sum ln_lab_inc_real [aweight=w11101] if syear==1998 & notworking==0
bysort edu: sum ln_lab_inc_real [aweight=w11101] if syear==2014 & notworking==0

********************************************************************************
* labour and total incomes
********************************************************************************
clear all
set more off
use "$root\data\preped2.dta", clear
gen gini_year=.
gen gini_lab_inc_ind=.
gen gini_lab_inc_hh=.

ineqdec0 lab_inc_real [aweight=w11101] if age>15 & age<66, by(syear)
local n = 1
forvalues i = 1997/2014 {
replace gini_lab_inc_ind= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}

ineqdec0 lab_inc_hh [aweight=w11101] if age>15 & age<66, by(syear)
local n = 1
forvalues i = 1997/2014 {
replace gini_lab_inc_hh= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}
********************************************************************************
* Household types
********************************************************************************
clear all
set more off
use "$root\data\preped2.dta", clear
keep if d11105==1
duplicates drop hid syear, force

gen group=4
replace group=1 if adults==1 & children==0
replace group=2 if adults==1 & children >0
replace group=3 if adults==2 & children==0

tab group [aweight=w11102] if syear==2014 , missing
tab group [aweight=w11102] if syear==2001 , missing

********************************************************************************
* incomes pre and post taxes
********************************************************************************
clear all
set more off
use "$root\data\preped2.dta", clear
gen gini_year=.
gen gini_hh_before=.
gen gini_hh_after=.
drop if age<16
drop if age>65
ineqdeco income_real_pre [aweight=w11101], by(syear)
local n = 1
forvalues i = 1997/2014 {
replace gini_hh_before= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}

ineqdeco income_real_post [aweight=w11101], by(syear)
local n = 1
forvalues i = 1997/2014 {
replace gini_hh_after= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}
********************************************************************************
* the role of public goods
********************************************************************************
clear all
set more off
use "$root\data\preped2.dta", clear
gen gini_year=.
gen gini_hh_post=.
gen gini_hh_health=.
drop if age<16
drop if age>65

ineqdeco income_real_post [aweight=w11101], by(syear)
local n = 1
forvalues i = 1997/2014 {
replace gini_hh_post= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}

ineqdeco income_edu_health_real [aweight=w11101], by(syear)
local n = 1
forvalues i = 1997/2014 {
replace gini_hh_health= r(gini_`i') in `n'
replace gini_year= `i' in `n'
local ++n
}
********************************************************************************
