* Project: govt size and redistribution
*
* Author: Michele Battisti
*
* Description: Open IMF dataset with govt share and controls
*
* Date created: April 8, 2014
* Last modified:
*
* Input: IMF data
* Output: cleaner IMF dataset

clear 
set more off
set linesize 255
capture log close

* Use relative paths from master.do
* Log file
log using $log\01.smcl, replace

* Open IMF World Economic Outlook dataset
insheet using $orig\imfweooct2015.csv

* Save and then erase annual data to save space
forvalues x=10/50 {
		replace v`x' = "." if v`x' == "n/a"
		replace v`x' = "." if v`x' == " "
		}
		
* Drop empty rows
drop if inlist(_n,1,_N)
drop if inlist(_n,1,_N)
	
* need to reshape, probably twice
* First get the years to be rows rather than columns
forvalues x=10/50 {
		local y = 1970+`x'
		rename v`x' y`y'
		}
* First reshape
reshape long y, i(country weosubjectcode ) j(year)
* Now need a second reshape. First give labels to subjects
* First need to give labels and drop variables that I will not need
encode weosubjectcode, gen(subjcode)
labmask subjcode , values( subjectdescriptor)
* Drop vars I no longer need
drop weocountrycode iso

* Brute force seems to be the only way
gen tempca = y if subjcode==1
destring tempca, replace force
bys country year : egen ca = max(tempca)
la var ca "Current account balance, in billions of USD"
drop tempca

gen tempcap = y if subjcode==2
destring tempcap, replace force
bys country year : egen cap = max(tempcap)
la var cap "Current account balance, share of GDP"
drop tempcap

gen templibor = y if subjcode==3
destring templibor, replace force
bys country year : egen libor = max(templibor)
la var libor "Six-month London interbank offered rate (LIBOR)"
drop templibor

gen tempgovrevenue = y if subjcode==4
destring tempgovrevenue, replace force
bys country year : egen govrevenue = max(tempgovrevenue)
la var govrevenue "General government revenues, in billions of national currency"
drop tempgovrevenue

gen tempgovrevenuep = y if subjcode==5
destring tempgovrevenuep, replace force
bys country year : egen govrevenuep = max(tempgovrevenuep)
la var govrevenuep "General government revenues, percent of GDP"
drop tempgovrevenuep

gen tempgovbal = y if subjcode==6
destring tempgovbal, replace force
bys country year : egen govbal = max(tempgovbal)
la var govbal "General government structural balance, in billions of national currency"
drop tempgovbal

gen tempgovbalp = y if subjcode==7
destring tempgovbalp, replace force
bys country year : egen govbalp = max(tempgovbalp)
la var govbalp "General government structural balance, percent of potential GDP"
drop tempgovbalp

gen tempgovexp = y if subjcode==8
destring tempgovexp, replace force
bys country year : egen govexp = max(tempgovexp)
la var govexp "General government total expenditures, in billions of national currency"
drop tempgovexp

gen tempgovlend = y if subjcode==9
destring tempgovlend, replace force
bys country year : egen govlend = max(tempgovlend)
la var govlend "General government net lending, in billions of national currency"
drop tempgovlend
	
gen tempgovlendp = y if subjcode==10
destring tempgovlendp, replace force
bys country year : egen govlendp = max(tempgovlendp)
la var govlendp "General government net lending, percent of GDP"
drop tempgovlendp

gen tempgovprimlend = y if subjcode==11
destring tempgovprimlend, replace force
bys country year : egen govprimlend = max(tempgovprimlend)
la var govprimlend "General government primary net lending, in billions of national currency"
drop tempgovprimlend

gen tempgovprimlendp = y if subjcode==12
destring tempgovprimlendp, replace force
bys country year : egen govprimlendp = max(tempgovprimlendp)
la var govprimlendp "General government primary net lending, percent of GDP"
drop tempgovprimlendp

gen tempgovgrossdebt = y if subjcode==13
destring tempgovgrossdebt, replace force
bys country year : egen govgrossdebt = max(tempgovgrossdebt)
la var govgrossdebt "General government gross debt, in billions of national currency"
drop tempgovgrossdebt

gen tempgovgrossdebtp = y if subjcode==14
destring tempgovgrossdebtp, replace force
bys country year : egen govgrossdebtp = max(tempgovgrossdebtp)
la var govgrossdebtp "General government gross debt, percent of GDP"
drop tempgovgrossdebtp

gen tempgovnetdebt = y if subjcode==15
destring tempgovnetdebt, replace force
bys country year : egen govnetdebt = max(tempgovnetdebt)
la var govnetdebt "General government net debt, in billions of national currency"
drop tempgovnetdebt

gen tempgovnetdebtp = y if subjcode==16
destring tempgovnetdebtp, replace force
bys country year : egen govnetdebtp = max(tempgovnetdebtp)
la var govnetdebtp "General government net debt, percent of GDP"
drop tempgovnetdebtp

gen tempgovexpp = y if subjcode==17
destring tempgovexpp, replace force
bys country year : egen govexpp = max(tempgovexpp)
la var govexpp "General government total expenditures, percent of GDP"
drop tempgovexpp

gen tempemp = y if subjcode==18
destring tempemp, replace force
bys country year : egen emp = max(tempemp)
la var emp "Employment, millions of people"
drop tempemp

gen temppop = y if subjcode==19
destring temppop, replace force
bys country year : egen pop = max(temppop)
la var pop "Population, millions of people"
drop temppop

gen tempu = y if subjcode==20
destring tempu, replace force
bys country year : egen u = max(tempu)
la var u "Unemployment rate, percent of total labour force"
drop tempu

* Output gap makes no sense for us
drop if subjcode==21

gen tempgdpcurrentlocal = y if subjcode==22
destring tempgdpcurrentlocal, replace force
bys country year : egen gdpcurrentlocal = max(tempgdpcurrentlocal)
la var gdpcurrentlocal "GDP at current prices, billions of national currency"
drop tempgdpcurrentlocal

gen tempgdpcurrentusd = y if subjcode==23
destring tempgdpcurrentusd, replace force
bys country year : egen gdpcurrentusd = max(tempgdpcurrentusd)
la var gdpcurrentusd "GDP at current prices, billions of U.S. dollars"
drop tempgdpcurrentusd

gen temppcgdpcurrentusd = y if subjcode==24
destring temppcgdpcurrentusd, replace force
bys country year : egen pcgdpcurrentusd = max(temppcgdpcurrentusd)
la var pcgdpcurrentusd "Per capita GDP at current prices, U.S. dollars"
drop temppcgdpcurrentusd

gen temppcgdpcurrentlocal = y if subjcode==25
destring temppcgdpcurrentlocal, replace force
bys country year : egen pcgdpcurrentlocal = max(temppcgdpcurrentlocal)
la var pcgdpcurrentlocal "Per capita GDP at current prices, national currency"
drop temppcgdpcurrentlocal

gen temppcgdpconstantlocal = y if subjcode==26
destring temppcgdpconstantlocal, replace force
bys country year : egen pcgdpconstantlocal = max(temppcgdpconstantlocal)
la var pcgdpconstantlocal "Per capita GDP at constant prices, national currency"
drop temppcgdpconstantlocal

gen tempgdpdeflator = y if subjcode==27
destring tempgdpdeflator, replace force
bys country year : egen gdpdeflator = max(tempgdpdeflator)
la var gdpdeflator "GDP deflator"
drop tempgdpdeflator

gen tempgdpcurrentlocalfiscal = y if subjcode==28
destring tempgdpcurrentlocalfiscal, replace force
bys country year : egen gdpcurrentlocalfiscal = max(tempgdpcurrentlocalfiscal)
la var gdpcurrentlocalfiscal "GDP at current prices, fiscal year, billions of national currency"
drop tempgdpcurrentlocalfiscal

gen tempgdpconstantlocal = y if subjcode==29
destring tempgdpconstantlocal, replace force
bys country year : egen gdpconstantlocal = max(tempgdpconstantlocal)
la var gdpconstantlocal "GDP at constant prices, billions of national currency"
drop tempgdpconstantlocal

gen tempgdpchangeconstantlocal = y if subjcode==30
destring tempgdpchangeconstantlocal, replace force
bys country year : egen gdpchangeconstantlocal = max(tempgdpchangeconstantlocal)
la var gdpchangeconstantlocal "GDP at constant prices, year-on-year percent change"
drop tempgdpchangeconstantlocal

gen tempgns = y if subjcode==31
destring tempgns, replace force
bys country year : egen gns = max(tempgns)
la var gns "Gross national savings as percentage of GDP"
drop tempgns

gen tempinvest = y if subjcode==32
destring tempinvest, replace force
bys country year : egen invest = max(tempinvest)
la var invest "Total investment as percentage of GDP"
drop tempinvest

gen tempinflation = y if subjcode==33
destring tempinflation, replace force
bys country year : egen inflation = max(tempinflation)
la var inflation "Inflation, average consumer prices"
drop tempinflation

gen tempinflationend = y if subjcode==34
destring tempinflationend, replace force
bys country year : egen inflationend = max(tempinflationend)
la var inflationend "Inflation, end of period consumer prices"
drop tempinflationend

gen tempchangeinflationend = y if subjcode==35
destring tempchangeinflationend, replace force
bys country year : egen changeinflationend = max(tempchangeinflationend)
la var changeinflationend "Inflation, end of period consumer prices, percent change"
drop tempchangeinflationend

gen tempchangeinflation = y if subjcode==36
destring tempchangeinflation, replace force
bys country year : egen changeinflation = max(tempchangeinflation)
la var changeinflation "Inflation, average consumer prices, percent change"
drop tempchangeinflation
	
* Implied PPP conversion rate: we will not need
drop if subjcode==37

gen tempgdpppp = y if subjcode==38
destring tempgdpppp, replace force
bys country year : egen gdpppp = max(tempgdpppp)
la var gdpppp "GDP based on PPP valuation of country GDP, billions of current international dollars"
drop tempgdpppp

gen temppcgdpppp = y if subjcode==39
destring temppcgdpppp, replace force
bys country year : egen pcgdpppp = max(temppcgdpppp)
la var pcgdpppp "Per capita GDP PPP, current international dollars"
drop temppcgdpppp

gen tempgdppppshare = y if subjcode==40
destring tempgdppppshare, replace force
bys country year : egen gdppppshare = max(tempgdppppshare)
la var gdppppshare "GDP PPP, share of world total"
drop tempgdppppshare

gen tempchangeimport = y if subjcode==41
destring tempchangeimport, replace force
bys country year : egen changeimport = max(tempchangeimport)
la var changeimport "Percent change in the volume of Imports of goods"
drop tempchangeimport

gen tempchangeimportgs = y if subjcode==42
destring tempchangeimportgs, replace force
bys country year : egen changeimportgs = max(tempchangeimportgs)
la var changeimportgs "Percent change in the volume of Imports of goods and services"
drop tempchangeimportgs

gen tempchangeexport = y if subjcode==43
destring tempchangeexport, replace force
bys country year : egen changeexport = max(tempchangeexport)
la var changeexport "Percent change in the volume of exports of goods"
drop tempchangeexport

gen tempchangeexportgs = y if subjcode==44
destring tempchangeexportgs, replace force
bys country year : egen changeexportgs = max(tempchangeexportgs)
la var changeexportgs "Percent change in the volume of exports of goods and services"
drop tempchangeexportgs
	
* I can now drop variables that I do not need and 
* then keep one observation for each country in each year
drop weosubjectcode subjectdescriptor subjectnotes ///
	units scale countryseriesspecificnotes y subjcode ///
	estimatesstartafter /* Need to drop since it is different for different variables */

* Ordering variables could be useful
duplicates drop
order country year emp pop u gdpcurrentlocal gdpcurrentusd pcgdpcurrentusd ///
	pcgdpcurrentlocal pcgdpconstantlocal gdpdeflator gdpcurrentlocalfiscal /// 
	gdpconstantlocal gdpchangeconstantlocal gdpppp pcgdpppp gdppppshare gov* 

* Can now compress and save dataset
compress
save $data\01.dta, replace
	
* Close log
log close
