* Project: govt size and redistribution
*
* Author: Michele Battisti
*
* Description: Clean SWIID summary dataset and merge into IMF clean data
*
* Date created: April 8, 2014
* Last modified: January 31, 2016
*
* Input: IMF (cleaned) and SWIID data (v5.0, 31 Jan 2016)
* Output: cleaner IMF dataset

clear 
set more off
set linesize 255
capture log close

* Use relative paths from master.do
* Log file
log using $log\02.smcl, replace


* Open swiid dataset and see whether there are things that I should do
use13 $orig/SWIIDv5_0.dta, clear
drop *abs_red*
drop *rel_red*

* Use code from SWIID website to get mean for each variable by country otherwise hard to work with mi datasets
keep country year _*

foreach v in gini_net gini_market {
    egen `v' = rowmean(_*`v')
    egen `v'_se = rowsd(_*`v')
    *gen `v'_95ub = `v' + 1.96*`v'_se
    *gen `v'_95lb = `v' - 1.96*`v'_se
}
drop _*
sort country year

* Things seem fine, label variables
la var gini_net "Gini Index, based on post tax, post transfer household income"
la var gini_net_se "Standard error of Gini Index, based on post tax, post transfer household income" 
la var gini_market "Gini Index, based on pre tax, pre transfer household income"
la var gini_market_se "Standard error of Gini Index, based on pre tax, pre transfer household income"
	
* Order point estimates first, then standard errors, which I may not need 
order country year gini_net gini_market gini_net_se gini_market_se

* Rename some values of the country variable otherwise I cannot merge
replace country="Democratic Republic of the Congo" if country=="Congo, Democratic Republic of"
replace country="Korea" if country=="Korea, Republic of"
replace country="Republic of Congo" if country=="Congo, Republic of"
replace country="Vietnam" if country=="Viet Nam"
replace country="Yemen" if country=="Yemen, Republic of"
replace country="Cote d'Ivoire" if country=="Cote d`Ivoire"

* Save dataset
save $data\02.swiid.dta, replace
	
* Now can open the imf dataset and merge in
use $data\01.dta, clear
* Rename some values of the country variable, otherwise I cannot merge
replace country="Cote d'Ivoire" if country=="Cte d'Ivoire"
replace country="Macedonia, FYR" if country=="FYR Macedonia"
replace country="Gambia" if country=="The Gambia"
replace country="Hong Kong" if country=="Hong Kong SAR"
replace country="Iran" if country=="Islamic Republic of Iran"
replace country="Lao" if country=="Lao P.D.R."
replace country="Russian Federation" if country=="Russia"
replace country="Taiwan" if country=="Taiwan Province of China"
replace country="Bahamas" if country=="The Bahamas"

* Merge
merge 1:1 country year using $data\01.02.swiid.dta
* Need to check well to make sure that
* non matched are not mismatched

* Done. Now I can keep merged only. Easy to go back on this if needed
keep if _merge==3
drop _merge
	
* Country is string, make it numeric
rename country countrystring
encode countrystring, gen(country)
order country

* Save
compress
save $data\02.dta, replace

* Erase datasets that are no longer needed
erase $data\01.dta
erase $data\02.swiid.dta
	
* Close log
log close
